==> haskell-criterion-measurement-0.2.3.0-49.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-GTVpwTo2u8PcyeGoHvPw3
key:                  criterion-measurement-0.2.3.0-GTVpwTo2u8PcyeGoHvPw3
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  fb4919042fc31212c975d7203f5066ac
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-GTVpwTo2u8PcyeGoHvPw3
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-prim-0.10.0
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.2.3.0-50-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion-measurement
version:              0.2.3.0
visibility:           public
id:                   criterion-measurement-0.2.3.0-gtGIRYSHl9ETYuz9xAQfL
key:                  criterion-measurement-0.2.3.0-gtGIRYSHl9ETYuz9xAQfL
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:
    Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/haskell/criterion
synopsis:             Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.

category:             Development, Performance, Testing, Benchmarking
abi:                  01bdb0f310c9f7befefef7475e4e041e
exposed:              True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-measurement-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion-measurement
hs-libraries:         HScriterion-measurement-0.2.3.0-gtGIRYSHl9ETYuz9xAQfL
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 binary-0.8.9.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-prim-0.10.0
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock

haddock-html:         /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
